@@ -22,7 +22,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
 USA.
 """
 
@@ -43,15 +43,14 @@ from sresults import SelectResults
 from util.threadinglocal import local
 
 import sys
-if sys.version_info[:3] < (2, 4, 0):
-    raise ImportError, "SQLObject requires Python 2.4.0 or later"
+if sys.version_info[:3] < (2, 5, 0):
+    raise ImportError, "SQLObject requires Python 2.5.0 or later"
 
 """
 This thread-local storage is needed for RowCreatedSignals. It gathers
 code-blocks to execute _after_ the whole hierachy of inherited SQLObjects
 is created. See SQLObject._create
 """
-_postponed_local = local()
 
 NoDefault = sqlbuilder.NoDefault
 
@@ -632,22 +631,8 @@ class sqlmeta(object):
 
 sqlhub = dbconnection.ConnectionHub()
 
-class _sqlmeta_attr(object):
 
-    def __init__(self, name, deprecation_level):
-        self.name = name
-        self.deprecation_level = deprecation_level
-
-    def __get__(self, obj, type=None):
-        if self.deprecation_level is not None:
-            deprecated(
-                'Use of this attribute should be replaced with '
-                '.sqlmeta.%s' % self.name, level=self.deprecation_level)
-        return getattr((type or obj).sqlmeta, self.name)
-
-
-# @@: This should become a public interface or documented or
-# something.  Turning it on gives earlier warning about things
+# Turning it on gives earlier warning about things
 # that will be deprecated (having this off we won't flood people
 # with warnings right away).
 warnings_level = 1
@@ -663,8 +648,8 @@ def deprecated(message, level=1, stacklevel=2):
     if warnings_level is not None and warnings_level <= level:
         warnings.warn(message, DeprecationWarning, stacklevel=stacklevel)
 
-#if sys.version_info[:3] < (2, 5, 0):
-#    deprecated("Support for Python 2.4 has been declared obsolete and will be removed in the next release of SQLObject")
+if sys.version_info[:3] < (2, 6, 0):
+    deprecated("Support for Python 2.5 has been declared obsolete and will be removed in the next release of SQLObject")
 
 def setDeprecationLevel(warning=1, exception=None):
     """
@@ -677,12 +662,11 @@ def setDeprecationLevel(warning=1, exception=None):
 
     The levels currently mean:
 
-      1) Deprecated in current version (0.9).  Will be removed in next
-         version (0.10)
+      1) Deprecated in current version.  Will be removed in next version.
 
       2) Planned to deprecate in next version, remove later.
 
-      3) Planned to deprecate sometime, remove sometime much later ;)
+      3) Planned to deprecate sometime, remove sometime much later.
 
     As the SQLObject versions progress, the deprecation level of
     specific features will go down, indicating the advancing nature of
@@ -698,6 +682,22 @@ def setDeprecationLevel(warning=1, exception=None):
     exception_level = exception
 
 
+class _sqlmeta_attr(object):
+
+    def __init__(self, name, deprecation_level):
+        self.name = name
+        self.deprecation_level = deprecation_level
+
+    def __get__(self, obj, type=None):
+        if self.deprecation_level is not None:
+            deprecated(
+                'Use of this attribute should be replaced with '
+                '.sqlmeta.%s' % self.name, level=self.deprecation_level)
+        return getattr((type or obj).sqlmeta, self.name)
+
+
+_postponed_local = local()
+
 # SQLObject is the superclass for all SQLObject classes, of
 # course.  All the deeper magic is done in MetaSQLObject, and
 # only lesser magic is done here.  All the actual work is done
@@ -1742,7 +1742,7 @@ def getObject(obj, klass):
     else:
         return obj
 
-__all__ = ['NoDefault', 'SQLObject', 'sqlmeta',
-           'getID', 'getObject',
-           'SQLObjectNotFound', 'sqlhub',
-           'setDeprecationLevel']
+__all__ = ['NoDefault', 'SQLObject',
+           'SQLObjectIntegrityError', 'SQLObjectNotFound',
+           'getID', 'getObject', 'sqlhub', 'sqlmeta',
+          ]
